colour.characterisation.dataset Package — Colour 0.3.0 documentation

# colour.characterisation.dataset Package

## Sub-Packages

- colour.characterisation.dataset.colour_checkers Package
  - Sub-Modules
    - colour.characterisation.dataset.colour_checkers.chromaticity_coordinates Module
      - ColourCheckers Chromaticity Coordinates
    - colour.characterisation.dataset.colour_checkers.spds Module
      - ColourCheckers Spectral Power Distributions
  - Module Contents

## Module Contents